==> material-ui-shell-1.0.2.tgz: package/es/containers/Menu/Menu.js <==
var _this = this,
    _jsxFileName = "C:\\github\\os\\react-most-wanted\\packages\\material-ui-shell\\src\\containers\\Menu\\Menu.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import clsx from 'clsx';
import { makeStyles, useTheme } from '@material-ui/core/styles';
import Drawer from '@material-ui/core/Drawer';
import CssBaseline from '@material-ui/core/CssBaseline';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import List from '@material-ui/core/List';
import Typography from '@material-ui/core/Typography';
import Divider from '@material-ui/core/Divider';
import IconButton from '@material-ui/core/IconButton';
import MenuIcon from '@material-ui/icons/Menu';
import ChevronLeftIcon from '@material-ui/icons/ChevronLeft';
import ChevronRightIcon from '@material-ui/icons/ChevronRight';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import InboxIcon from '@material-ui/icons/MoveToInbox';
import MailIcon from '@material-ui/icons/Mail';
import { compose } from 'redux';
import { connect } from 'react-redux';
import drawerActions from '../../store/drawer/actions';
import { withRouter } from 'react-router-dom';
import { default as withAppConfigs } from 'base-shell/lib/providers/ConfigProvider/withConfig';
import { injectIntl } from 'react-intl';
var drawerWidth = 240;
var useStyles = makeStyles(function (theme) {
  return {
    root: {
      display: 'flex'
    },
    appBar: {
      transition: theme.transitions.create(['margin', 'width'], {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      })
    },
    appBarShift: {
      width: "calc(100% - " + drawerWidth + "px)",
      marginLeft: drawerWidth,
      transition: theme.transitions.create(['margin', 'width'], {
        easing: theme.transitions.easing.easeOut,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    menuButton: {
      marginRight: theme.spacing(2)
    },
    hide: {
      display: 'none'
    },
    drawer: {
      width: drawerWidth,
      flexShrink: 0
    },
    drawerPaper: {
      width: drawerWidth
    },
    drawerHeader: _extends({
      display: 'flex',
      alignItems: 'center',
      padding: theme.spacing(0, 1)
    }, theme.mixins.toolbar, {
      justifyContent: 'flex-end'
    }),
    content: {
      flexGrow: 1,
      padding: theme.spacing(3),
      transition: theme.transitions.create('margin', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      }),
      marginLeft: -drawerWidth
    },
    contentShift: {
      transition: theme.transitions.create('margin', {
        easing: theme.transitions.easing.easeOut,
        duration: theme.transitions.duration.enteringScreen
      }),
      marginLeft: 0
    }
  };
});

var Menu = function Menu(_ref) {
  var drawer = _ref.drawer,
      setDrawerOpen = _ref.setDrawerOpen,
      setDrawerMobileOpen = _ref.setDrawerMobileOpen,
      appConfig = _ref.appConfig,
      intl = _ref.intl,
      match = _ref.match,
      history = _ref.history;
  var classes = useStyles();
  var theme = useTheme();
  var _drawer$open = drawer.open,
      open = _drawer$open === void 0 ? false : _drawer$open;
  var menuItems = appConfig.getMenuItems({
    intl: intl,
    auth: appConfig.auth //locale,
    //updateLocale,

  }).filter(function (item) {
    return item.visible !== false;
  });

  var handleDrawerOpen = function handleDrawerOpen() {
    setDrawerOpen(true);
  };

  var handleDrawerClose = function handleDrawerClose() {
    setDrawerOpen(false);
  };

  var index = match ? match.path : '/';

  var onIndexChange = function onIndexChange(event, index) {
    if (index !== undefined) {
      setDrawerMobileOpen(false);
    }

    if (index !== undefined && index !== Object(index)) {
      history.push(index);
    }
  };

  var useMinified = drawer.useMinified && !drawer.open;

  var getItem = function getItem(item, i) {
    //delete item.visible
    if (item !== undefined) {
      if (item.subheader !== undefined) {
        return /*#__PURE__*/React.createElement("div", {
          key: i,
          inset: item.inset,
          style: item.style,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 130,
            columnNumber: 11
          }
        }, item.subheader);
      } else if (item.divider !== undefined) {
        return /*#__PURE__*/React.createElement(Divider, {
          key: i,
          inset: item.inset,
          style: item.style,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 135,
            columnNumber: 16
          }
        });
      } else {
        return /*#__PURE__*/React.createElement(ListItem, {
          button: true,
          selected: index && index === item.value,
          key: i,
          onClick: function onClick(e) {
            onIndexChange(e, item.value); // this.handleNestedItemsClick(item)

            if (item.onClick) {
              item.onClick();
            }
          },
          onMouseDown: function onMouseDown(e) {
            if (e.button === 1) {
              var win = window.open("" + item.value, '_blank');
              win.focus();
            }
          },
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 138,
            columnNumber: 11
          }
        }, item.leftIcon && /*#__PURE__*/React.createElement(ListItemIcon, {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 156,
            columnNumber: 31
          }
        }, item.leftIcon), !useMinified && /*#__PURE__*/React.createElement(ListItemText, {
          primary: item.primaryText,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 158,
            columnNumber: 30
          }
        }));
      }
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(Drawer, {
    className: classes.drawer,
    variant: "persistent",
    anchor: "left",
    open: open,
    classes: {
      paper: classes.drawerPaper
    },
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 180,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.drawerHeader,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 189,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(IconButton, {
    onClick: handleDrawerClose,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 190,
      columnNumber: 9
    }
  }, theme.direction === 'ltr' ? /*#__PURE__*/React.createElement(ChevronLeftIcon, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 192,
      columnNumber: 13
    }
  }) : /*#__PURE__*/React.createElement(ChevronRightIcon, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 194,
      columnNumber: 15
    }
  }))), /*#__PURE__*/React.createElement(Divider, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 198,
      columnNumber: 7
    }
  }), /*#__PURE__*/React.createElement(List, {
    value: index,
    onChange: onIndexChange,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 199,
      columnNumber: 7
    }
  }, menuItems.filter(function (item) {
    return item.visible !== false;
  }).map(function (item, i) {
    return getItem(item, i);
  })));
};

var mapStateToProps = function mapStateToProps(state) {
  var drawer = state.drawer;
  return {
    drawer: drawer
  };
};

export default compose(connect(mapStateToProps, _extends({}, drawerActions)), injectIntl, withRouter, withAppConfigs)(Menu);

==> material-ui-shell-1.0.3.tgz: package/es/containers/Menu/Menu.js <==
var _this = this,
    _jsxFileName = "C:\\github\\os\\react-most-wanted\\packages\\material-ui-shell\\src\\containers\\Menu\\Menu.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useContext } from 'react';
import clsx from 'clsx';
import { makeStyles, useTheme } from '@material-ui/core/styles';
import Drawer from '@material-ui/core/Drawer';
import SwipeableDrawer from '@material-ui/core/SwipeableDrawer';
import CssBaseline from '@material-ui/core/CssBaseline';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import List from '@material-ui/core/List';
import Typography from '@material-ui/core/Typography';
import Divider from '@material-ui/core/Divider';
import IconButton from '@material-ui/core/IconButton';
import MenuIcon from '@material-ui/icons/Menu';
import ChevronLeftIcon from '@material-ui/icons/ChevronLeft';
import ChevronRightIcon from '@material-ui/icons/ChevronRight';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import InboxIcon from '@material-ui/icons/MoveToInbox';
import MailIcon from '@material-ui/icons/Mail';
import { useHistory, useRouteMatch } from 'react-router-dom';
import ConfigContext from 'base-shell/lib/providers/Config/Context';
import MenuContext from '../../providers/Menu/Context';
import { useIntl } from 'react-intl';
import useMediaQuery from '@material-ui/core/useMediaQuery';
var drawerWidth = 240;
var useStyles = makeStyles(function (theme) {
  return {
    root: {
      display: 'flex'
    },
    appBar: {
      transition: theme.transitions.create(['margin', 'width'], {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      })
    },
    appBarShift: {
      width: "calc(100% - " + drawerWidth + "px)",
      marginLeft: drawerWidth,
      transition: theme.transitions.create(['margin', 'width'], {
        easing: theme.transitions.easing.easeOut,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    menuButton: {
      marginRight: theme.spacing(2)
    },
    hide: {
      display: 'none'
    },
    drawer: {
      width: drawerWidth,
      flexShrink: 0
    },
    drawerPaper: {
      width: drawerWidth
    },
    drawerHeader: _extends(_extends({
      display: 'flex',
      alignItems: 'center',
      padding: theme.spacing(0, 1)
    }, theme.mixins.toolbar), {}, {
      justifyContent: 'flex-end'
    }),
    content: {
      flexGrow: 1,
      padding: theme.spacing(3),
      transition: theme.transitions.create('margin', {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      }),
      marginLeft: -drawerWidth
    },
    contentShift: {
      transition: theme.transitions.create('margin', {
        easing: theme.transitions.easing.easeOut,
        duration: theme.transitions.duration.enteringScreen
      }),
      marginLeft: 0
    }
  };
});

var Menu = function Menu() {
  var intl = useIntl();
  var history = useHistory();
  var match = useRouteMatch();
  var classes = useStyles();
  var theme = useTheme();
  var isDesktop = useMediaQuery('(min-width:600px)');

  var _useContext = useContext(MenuContext),
      isDesktopOpen = _useContext.isDesktopOpen,
      isMobileOpen = _useContext.isMobileOpen,
      isMini = _useContext.isMini,
      setDesktopOpen = _useContext.setDesktopOpen,
      setMobileOpen = _useContext.setMobileOpen;

  var _useContext2 = useContext(ConfigContext),
      appConfig = _useContext2.appConfig;

  var menuItems = appConfig.getMenuItems({
    intl,
    auth: appConfig.auth
  }).filter(function (item) {
    return item.visible !== false;
  });

  var handleDrawerClose = function handleDrawerClose() {
    if (isDesktop) {
      setDesktopOpen(false);
    } else {
      setMobileOpen(false);
    }
  };

  var index = match ? match.path : '/';

  var onIndexChange = function onIndexChange(event, index) {
    if (index !== undefined) {
      setMobileOpen(false);
    }

    if (index !== undefined && index !== Object(index)) {
      history.push(index);
    }
  };

  var getItem = function getItem(item, i) {
    //delete item.visible
    if (item !== undefined) {
      if (item.subheader !== undefined) {
        return /*#__PURE__*/React.createElement("div", {
          key: i,
          inset: item.inset,
          style: item.style,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 138,
            columnNumber: 11
          }
        }, item.subheader);
      } else if (item.divider !== undefined) {
        return /*#__PURE__*/React.createElement(Divider, {
          key: i,
          inset: item.inset,
          style: item.style,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 143,
            columnNumber: 16
          }
        });
      } else {
        return /*#__PURE__*/React.createElement(ListItem, {
          button: true,
          selected: index && index === item.value,
          key: i,
          onClick: function onClick(e) {
            onIndexChange(e, item.value); // this.handleNestedItemsClick(item)

            if (item.onClick) {
              item.onClick();
            }
          },
          onMouseDown: function onMouseDown(e) {
            if (e.button === 1) {
              var win = window.open("" + item.value, '_blank');
              win.focus();
            }
          },
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 146,
            columnNumber: 11
          }
        }, item.leftIcon && /*#__PURE__*/React.createElement(ListItemIcon, {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 164,
            columnNumber: 31
          }
        }, item.leftIcon), !isMini && /*#__PURE__*/React.createElement(ListItemText, {
          primary: item.primaryText,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 166,
            columnNumber: 25
          }
        }));
      }
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(SwipeableDrawer, {
    className: classes.drawer,
    variant: isDesktop ? 'persistent' : 'temporary',
    anchor: "left",
    open: isDesktop ? isDesktopOpen : isMobileOpen,
    onClose: function onClose() {
      setMobileOpen(false);
    },
    onOpen: function onOpen() {
      setMobileOpen(true);
    },
    classes: {
      paper: classes.drawerPaper
    },
    ModalProps: {
      keepMounted: true // Better open performance on mobile.

    },
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 188,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.drawerHeader,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 206,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(IconButton, {
    onClick: handleDrawerClose,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 207,
      columnNumber: 9
    }
  }, theme.direction === 'ltr' ? /*#__PURE__*/React.createElement(ChevronLeftIcon, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 209,
      columnNumber: 13
    }
  }) : /*#__PURE__*/React.createElement(ChevronRightIcon, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 211,
      columnNumber: 13
    }
  }))), /*#__PURE__*/React.createElement(Divider, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 215,
      columnNumber: 7
    }
  }), /*#__PURE__*/React.createElement(List, {
    value: index,
    onChange: onIndexChange,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 216,
      columnNumber: 7
    }
  }, menuItems.filter(function (item) {
    return item.visible !== false;
  }).map(function (item, i) {
    return getItem(item, i);
  })));
};

export default Menu;
